/**
 * @author Mike Tung <miketung2013@gmail.com>
 * @license
 * Copyright Mike Tung All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file
 */
import { Injectable } from '@angular/core';
import * as d3 from 'd3';
export class DataService {
    constructor() {
    }
    /**
     * This is a method to parse out the data to be visualized
     *
     *
     * @param {?} data
     * @param {?} dataElement
     * @return {?}
     */
    getData(data, dataElement) {
        return data.map((d) => d[dataElement]);
    }
    /**
     * This method creates any kind of d3 scale using builder pattern
     *
     *
     * @param {?} scaleType
     * @param {?} data
     * @param {?} measure
     * @param {?=} ordered
     * @return {?}
     */
    makeScale(scaleType, data, measure, ordered = true) {
        const /** @type {?} */ scaleOptions = {
            'linear': this.makeLinearScale(data, measure, ordered),
            'categorical': this.makeCategoricalScale(data, measure, ordered),
            'time': this.makeTimeScale(data, measure, ordered)
        };
        return scaleOptions[scaleType];
    }
    /**
     * @param {?} data
     * @param {?} measure
     * @param {?=} ordered
     * @return {?}
     */
    makeLinearScale(data, measure, ordered = true) {
        if (ordered) {
            return d3.scaleLinear().domain([0, d3.max(data)]).rangeRound([0, measure]);
        }
        return d3.scaleLinear().domain([0, d3.max(data)]).rangeRound([measure, 0]);
    }
    /**
     * @param {?} data
     * @param {?} measure
     * @param {?=} ordered
     * @return {?}
     */
    makeCategoricalScale(data, measure, ordered = true) {
        if (ordered) {
            return d3.scaleBand().domain(data).rangeRound([0, measure]);
        }
        else {
            return d3.scaleBand().domain(data).rangeRound([0, measure]);
        }
    }
    /**
     * @param {?} data
     * @param {?} measure
     * @param {?=} ordered
     * @return {?}
     */
    makeTimeScale(data, measure, ordered = true) {
        if (ordered) {
            return d3.scaleTime().domain(d3.extent(data)).rangeRound([0, measure]);
        }
        else {
            return d3.scaleTime().domain(data).rangeRound([0, measure]);
        }
    }
}
DataService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DataService.ctorParameters = () => [];
function DataService_tsickle_Closure_declarations() {
    /** @type {?} */
    DataService.decorators;
    /**
     * @nocollapse
     * @type {?}
     */
    DataService.ctorParameters;
}
//# sourceMappingURL=data.service.js.map