/**
 * @author Mike Tung <miketung2013@gmail.com>
 * @license
 * Copyright Mike Tung All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file
 */
import { Injectable } from '@angular/core';
import * as d3 from 'd3';
export class ToolTipService {
    /**
     * A method to add tooltips to a d3 selection object, tooltip will show x, y datapoints and
     * any meta data mentioned in message property
     *
     *
     * @param {?} selection
     * @param {?} labelKeys
     * @param {?} refElement
     * @return {?}
     */
    addTooltip(selection, labelKeys, refElement) {
        const /** @type {?} */ tooltipBoxContainer = refElement.nativeElement;
        const /** @type {?} */ tooltipBox = d3.select(tooltipBoxContainer)
            .append('div')
            .attr('class', 'tooltip')
            .style('opacity', 0);
        return selection
            .on('mouseover', (d) => {
            const /** @type {?} */ content = `${labelKeys.x}: ${d[labelKeys.x]}<br/>${labelKeys.y}: ${d[labelKeys.y]}`;
            let /** @type {?} */ box;
            tooltipBox
                .transition()
                .duration(200)
                .style('opacity', 0.95);
            if (labelKeys.message !== null) {
                const /** @type {?} */ message = `${labelKeys.message}: ${d[labelKeys.message]}`;
                box = tooltipBox.html(`<p>${content}<br/>${message}</p>`);
            }
            else {
                box = tooltipBox.html(`<p>${content}</p>`);
            }
            box
                .style('left', `${d3.event.pageX}px`)
                .style('top', `${d3.event.pageY}px`)
                .style('position', 'absolute')
                .style('text-align', 'center')
                .style('width', '6%')
                .style('height', '8%')
                .style('padding', '5px')
                .style('line-height', 1)
                .style('font-family', 'sans-serif')
                .style('font-size', '1em')
                .style('color', '#fff')
                .style('background', 'lightsteelblue')
                .style('border', 0)
                .style('word-wrap', 'break-word')
                .style('overflow', 'hidden')
                .style('border-radius', '8px')
                .style('pointer-events', 'none');
        })
            .on('mouseout', (d) => {
            tooltipBox.transition()
                .duration(500)
                .style('opacity', 0);
        });
    }
}
ToolTipService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ToolTipService.ctorParameters = () => [];
function ToolTipService_tsickle_Closure_declarations() {
    /** @type {?} */
    ToolTipService.decorators;
    /**
     * @nocollapse
     * @type {?}
     */
    ToolTipService.ctorParameters;
}
//# sourceMappingURL=tooltip.service.js.map